#
# spec file for package jetty-unixsocket
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2000-2007, JPackage Project
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name jetty
%global addver  .v20240208
%define src_name %{base_name}.project-%{base_name}-%{version}%{addver}
Name:           %{base_name}-unixsocket
Version:        9.4.54
Release:        1.2
Summary:        The unixsocket modules for Jetty
License:        Apache-2.0 OR EPL-1.0
URL:            https://www.eclipse.org/jetty/
Source0:        https://github.com/eclipse/%{base_name}.project/archive/%{base_name}-%{version}%{addver}.tar.gz#/%{src_name}.tar.gz
BuildRequires:  fdupes
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(com.github.jnr:jnr-unixsocket)
BuildRequires:  mvn(org.apache.ant:ant)
BuildRequires:  mvn(org.apache.felix:maven-bundle-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-antrun-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-dependency-plugin)
BuildRequires:  mvn(org.codehaus.mojo:build-helper-maven-plugin)
BuildRequires:  mvn(org.eclipse.jetty:jetty-client) >= %{version}
BuildRequires:  mvn(org.eclipse.jetty:jetty-server) >= %{version}
BuildArch:      noarch

%description
Jetty is a 100% Java HTTP Server and Servlet Container. This means that you\
do not need to configure and run a separate web server (like Apache) in order\
to use Java, servlets and JSPs to generate dynamic content. Jetty is a fully\
featured web server for static and dynamic content. Unlike separate\
server/container solutions, this means that your web server and web\
application run in the same process, without interconnection overheads\
and complications. Furthermore, as a pure java component, Jetty can be simply\
included in your application for demonstration, distribution or deployment.\
Jetty is available on all Java supported platforms.

This package contains the unixsocket module for Jetty

%package        javadoc
Summary:        Javadoc for %{name}

%description    javadoc
%{summary}.

%prep
%setup -q -n %{src_name}

find . -name "*.?ar" -exec rm {} \;
find . -name "*.class" -exec rm {} \;

%pom_remove_dep :::import

# Plugins irrelevant or harmful to building the package
%pom_remove_plugin -r :maven-checkstyle-plugin
%pom_remove_plugin -r :maven-enforcer-plugin
%pom_remove_plugin -r :maven-eclipse-plugin
%pom_remove_plugin -r :license-maven-plugin
%pom_remove_plugin -r :maven-site-plugin
%pom_remove_plugin -r :maven-source-plugin
%pom_remove_plugin -r :maven-deploy-plugin
%pom_remove_plugin -r :jacoco-maven-plugin
%pom_remove_plugin -r :maven-release-plugin
%pom_remove_plugin -r :buildnumber-maven-plugin
%pom_remove_plugin -r :h2spec-maven-plugin

# Unnecessary pom flattening can be skipped
%pom_remove_plugin -r :flatten-maven-plugin jetty-bom

%pom_disable_module aggregates/jetty-all

%pom_xpath_inject "pom:configuration/pom:instructions" \
"<Import-Package>sun.misc;resolution:=optional,com.sun.nio.file;resolution:=optional,*</Import-Package>"

%pom_remove_dep "com.sun.net.httpserver:http" jetty-http-spi

%pom_change_dep -r org.mortbay.jasper:apache-jsp org.apache.tomcat:tomcat-jasper

%pom_add_dep 'org.junit.jupiter:junit-jupiter-engine:${junit.version}' tests/test-sessions/test-sessions-common

# provided by glassfish-jsp-api that has newer version
%pom_change_dep -r javax.servlet.jsp:jsp-api javax.servlet.jsp:javax.servlet.jsp-api

# txt artifact - not installable
%pom_remove_plugin ":jetty-version-maven-plugin"
%pom_xpath_remove "pom:artifactItem[pom:classifier='version']" jetty-home

# Disable building source release
%pom_xpath_remove 'pom:execution[pom:id="sources"]' jetty-home

# Unwanted JS in javadoc
sed -i '/^\s*\*.*<script>/d' jetty-util/src/main/java/org/eclipse/jetty/util/resource/Resource.java

# only used for integration tests
%pom_remove_plugin :maven-invoker-plugin jetty-jspc-maven-plugin

# These bundles have a dep on Eclipse that is not available on every arch
%pom_disable_module jetty-osgi

# We don't have asciidoctor-maven-plugin
%pom_disable_module jetty-documentation
%pom_remove_dep -r :jetty-documentation
%pom_xpath_remove 'pom:execution[pom:id="unpack-documentation"]' jetty-distribution

%pom_xpath_remove 'pom:artifactItem[pom:artifactId="libsetuid-osx"]' jetty-home/pom.xml

# TODO remove when jetty-setuid is packaged
%pom_xpath_remove "pom:execution[pom:id[text()='copy-setuid-deps']]" jetty-home/pom.xml

# We don't have gcloud-java-datastore
%pom_disable_module jetty-gcloud
%pom_disable_module test-gcloud-sessions tests/test-sessions
%pom_remove_dep :jetty-gcloud-session-manager jetty-home

# we don't have com.googlecode.xmemcached:xmemcached yet
%pom_disable_module jetty-memcached
%pom_disable_module test-memcached-sessions tests/test-sessions
%pom_remove_dep :jetty-memcached-sessions jetty-home

# We don't have hazelcast
%pom_disable_module jetty-hazelcast
%pom_disable_module test-hazelcast-sessions tests/test-sessions
%pom_remove_dep :jetty-hazelcast jetty-home

# We don't have infinispan
%pom_disable_module jetty-infinispan
%pom_disable_module test-infinispan-sessions tests/test-sessions
%pom_remove_dep :infinispan-embedded jetty-home
%pom_remove_dep :infinispan-embedded-query jetty-home
%pom_remove_dep :infinispan-remote jetty-home
%pom_remove_dep :infinispan-remote-query jetty-home
%pom_xpath_remove "pom:execution[pom:id='unpack-infinispan-config']" jetty-home

# Not currently able to build tests, so can't build benchmarks
%pom_disable_module jetty-jmh

# Distribution tests require internet access, so disable
%pom_disable_module test-distribution tests

# missing conscrypt
%pom_disable_module jetty-alpn-conscrypt-server jetty-alpn
%pom_disable_module jetty-alpn-conscrypt-client jetty-alpn
%pom_remove_dep -r :jetty-alpn-conscrypt-server
%pom_remove_dep -r :jetty-alpn-conscrypt-client
rm -fr examples/embedded/src/main/java/org/eclipse/jetty/embedded/ManyConnectors.java

# the default location is not allowed by SELinux
sed -i '/<SystemProperty name="jetty.state"/d' \
    jetty-home/src/main/resources%{_sysconfdir}/jetty-started.xml

# remote-resources only copies about.html
%pom_remove_plugin :maven-remote-resources-plugin
# packages module configs, we don't need those in minimal
%pom_remove_plugin -r :maven-assembly-plugin
# only useful when tests are enabled (copies test deps)
%pom_remove_plugin :maven-dependency-plugin jetty-client

# all modules besides the current jetty-unixsocket
%pom_disable_module jetty-ant
%pom_disable_module jetty-http2
%pom_disable_module jetty-fcgi
%pom_disable_module jetty-servlets
%pom_disable_module apache-jstl
%pom_disable_module jetty-maven-plugin
%pom_disable_module jetty-jspc-maven-plugin
%pom_disable_module jetty-deploy
%pom_disable_module jetty-start
%pom_disable_module jetty-cdi
%pom_disable_module jetty-spring
%pom_disable_module jetty-jaspi
%pom_disable_module jetty-rewrite
%pom_disable_module jetty-nosql
%pom_disable_module tests
%pom_disable_module examples
%pom_disable_module jetty-quickstart
%pom_disable_module jetty-distribution
%pom_disable_module jetty-runner
%pom_disable_module jetty-http-spi
%pom_disable_module jetty-alpn
%pom_disable_module jetty-home
%pom_disable_module jetty-websocket

# minimal modules built in jetty-minimal package
%pom_disable_module jetty-annotations
%pom_disable_module jetty-client
%pom_disable_module jetty-continuation
%pom_disable_module jetty-http
%pom_disable_module jetty-io
%pom_disable_module jetty-jaas
%pom_disable_module jetty-jmx
%pom_disable_module jetty-jndi
%pom_disable_module apache-jsp
%pom_disable_module jetty-openid
%pom_disable_module jetty-plus
%pom_disable_module jetty-proxy
%pom_disable_module jetty-security
%pom_disable_module jetty-server
%pom_disable_module jetty-servlet
%pom_disable_module jetty-util
%pom_disable_module jetty-util-ajax
%pom_disable_module jetty-xml
%pom_disable_module jetty-webapp

%pom_xpath_remove "pom:plugins/pom:plugin[pom:artifactId='maven-javadoc-plugin']/pom:configuration/pom:additionalJOption"

%{mvn_file} :{*} %{base_name}/@1

%build

%{mvn_package} :jetty-home __noinstall
%{mvn_package} :jetty-distribution __noinstall

# Separate package for POMs
%{mvn_package} ':*-project' __noinstall
%{mvn_package} ':*-parent' __noinstall
%{mvn_package} ':*-bom' __noinstall

# artifact used by demo
%{mvn_package} :test-mock-resources

%{mvn_package} ':test-*' __noinstall
%{mvn_package} ':*-tests' __noinstall
%{mvn_package} ':*-it' __noinstall
%{mvn_package} ':example-*' __noinstall
%{mvn_package} org.eclipse.jetty.tests: __noinstall
%{mvn_package} ::war: __noinstall
%{mvn_package} :jetty-runner __noinstall
%{mvn_package} :build-resources __noinstall

%{mvn_build} -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    -Dsource=8

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles

%files javadoc -f .mfiles-javadoc
%license LICENSE NOTICE.txt

%changelog
* Tue Feb 27 2024 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 9.4.54.v20240208
  * Security fixes
    + CVE-2024-22201, bsc#1220437: HTTP/2 connection not closed
    after idle timeout when TCP congested
  * Other changes
    + #1256 DoSFilter leaks USER_AUTH entries
    + #11389 Strip default ports on ws/wss scheme uris too
* Thu Oct 12 2023 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 9.4.53.v20231009
  * Fixes of 9.4.53.v20231009
    + CVE-2023-44487, bsc#1216169
    + CVE-2023-36478, bsc#1216162
    + #10679 - backport HTTP/2 rate control from Jetty 10.0.x
    + #10573 - backport hpack improvements from Jetty 10.0.x
    + #10546 - backport jetty-http Huffman encoders/decoders from
    Jetty 10.0.x
  * Fixes of 9.4.52.v20230823
    + #10352 - Jetty accepts "+" prefixed value in Content-Length
    (CVE-2023-40167, bsc#1215417)
    + #10337 - SizeLimitHandler does not enforce 0 responseLimit
    + #10169 - make sure that a ServiceLoader is retrieved before
    iterating
    + #10066 - Allow SAXParserFactory or SAXParser to be configured
    in Jetty's XmlParser class - Allows for GHSA-58qw-p7qm-5rvh
    workaround
    + #9887 - Deprecate CGI Servlet (CVE-2023-36479, bsc#1215415)
    + #9716 - Deprecate PushSessionCacheFilter
    + #9660 - OpenId Revoked authentication allows one request
    (CVE-2023-41900, bsc#1215416)
    + #9476 - onCompleteFailure called multiple times
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Sun May 21 2023 Fridrich Strba <fstrba@suse.com>
- Update to version 9.4.51.v20230217
  * Fixes of 9.4.49.v20220914:
    + #8578 - getRequestURL can append "null" if getRequestURI is
    unspecified in an authority-form request-target
    + #8493 - Review HTTP client feature setRemoveIdleDestinations
  * Fixes of 9.4.50.v20221201:
    + #8774 - Added SizeLimitHandler
    + #8678 - Jetty client is not responding to GO_AWAY packet
    received from (Jetty) Server and continue to send traffic on
    same connection
  * Fixes of 9.4.51.v20230217:
    + #9352 - Update / Fix CookieCutter
    + #9345 - Backport Multipart Fix for CVE-2023-26048, bsc#1210620
    + #9352 - Backport Cookie Parsing Fix for CVE-2023-26049,
    bsc#1210621
* Fri Jul  8 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 9.4.48.v20220622
  * Fixes
    + #8184 - All suffix globs except first fail to match if path
    has "." character in prefix section
    + #8145 - RegexPathSpec backport of optional group name/info
    lookup if regex fails
    + #8088 - Add option to configure exitVm on ShutdownMonitor from
    System properties
    + #8067 - Wall time usage in DoSFilter RateTracker results in
    false positive alert
    + #8014 - Review HttpRequest URI construction (Resolves
    CVE-2022-2047, bsc#1201317)
    + #7976 - Add TRANSFER_ENCODING violation for MultiPart RFC7578
    parser
    + #7947 - Improved PathSpec handling for servletName & pathInfo
    + #7935 - Review HTTP/2 error handling (Resolves CVE-2022-2048,
    bsc#1201316)
    + #7918 - PathMappings.asPathSpec does not allow root
    ServletPathSpec
    + #7863 - Default servlet drops first accept-encoding header if
    there is more than one.
    + #7858 - GZipHandler does not play nice with other handlers in
    HandlerCollection
    + #7837 - Fix StatisticsHandler in the case a Handler throws
    exception
    + #7809 - Jetty 9.4.x 7801 duplicate set session cookies
    + #7748 - Allow overriding of url-pattern mapping in
    ServletContextHandler to allow for regex or uri-template
    matching
* Tue Mar 29 2022 Fridrich Strba <fstrba@suse.com>
- Upgrade to version 9.4.46.v20220328
  * Changes
    + Option --write-module-graph produces wrong .dot file
    + ArrayTrie getBest fails to match the empty string entry in
    certain cases
    + Interrupt flag is not always cleared in between requests
    + Gzip compression not working for multipart/form-data when
    added to the allowed list using addIncludedMimeTypes.
    + Miconfigured headerCacheSize in can result in
    IllegalArgumentException
    + HttpServletResponse.encodeURL not working for URLs starting
    with ../
* Tue Mar 22 2022 Fridrich Strba <fstrba@suse.com>
- Build with java source and target levels 8
- Fix javadoc generation on JDK >= 13
* Tue Oct 19 2021 Fridrich Strba <fstrba@suse.com>
- Make importing of package sun.misc optional since not all jdk
  versions export it
* Mon Jul 19 2021 Fridrich Strba <fstrba@suse.com>
- Splitting jetty-unixsocket 9.4.43.v20210629 into a separate spec
  file
